EXPORTS
	?PlaceholderForRemovedExport1@CMDXMLDocument@@AAEXAAVMXMLDtd@@@Z @ 1 NONAME ; private: void __thiscall CMDXMLDocument::PlaceholderForRemovedExport1(class MXMLDtd &)
	??0CMDXMLElement@@IAE@HPAVCMDXMLDocument@@@Z @ 2 NONAME ; protected: __thiscall CMDXMLElement::CMDXMLElement(int,class CMDXMLDocument *)
	??1CMDXMLCDATASection@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CMDXMLCDATASection::~CMDXMLCDATASection(void)
	??1CMDXMLCharacterData@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CMDXMLCharacterData::~CMDXMLCharacterData(void)
	??1CMDXMLComment@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CMDXMLComment::~CMDXMLComment(void)
	??1CMDXMLDocument@@UAE@XZ @ 6 NONAME ; public: virtual __thiscall CMDXMLDocument::~CMDXMLDocument(void)
	??1CMDXMLDocumentElement@@UAE@XZ @ 7 NONAME ; public: virtual __thiscall CMDXMLDocumentElement::~CMDXMLDocumentElement(void)
	??1CMDXMLElement@@UAE@XZ @ 8 NONAME ; public: virtual __thiscall CMDXMLElement::~CMDXMLElement(void)
	??1CMDXMLNode@@UAE@XZ @ 9 NONAME ; public: virtual __thiscall CMDXMLNode::~CMDXMLNode(void)
	??1CMDXMLProcessingInstruction@@UAE@XZ @ 10 NONAME ; public: virtual __thiscall CMDXMLProcessingInstruction::~CMDXMLProcessingInstruction(void)
	??1CMDXMLText@@UAE@XZ @ 11 NONAME ; public: virtual __thiscall CMDXMLText::~CMDXMLText(void)
	?AppendChild@CMDXMLNode@@QAEHPAV1@@Z @ 12 NONAME ; public: int __thiscall CMDXMLNode::AppendChild(class CMDXMLNode *)
	?AppendL@CMDXMLCharacterData@@UAEXAAVTDesC16@@@Z @ 13 NONAME ; public: virtual void __thiscall CMDXMLCharacterData::AppendL(class TDesC16 &)
	?AttributeDetails@CMDXMLElement@@QAEHHAAVTPtrC16@@0@Z @ 14 NONAME ; public: int __thiscall CMDXMLElement::AttributeDetails(int,class TPtrC16 &,class TPtrC16 &)
	?CanElementHaveChildren@CMDXMLDocument@@QBEHABVTDesC16@@@Z @ 15 NONAME ; public: int __thiscall CMDXMLDocument::CanElementHaveChildren(class TDesC16 const &)const 
	?CheckChildren@CMDXMLCharacterData@@UAEHXZ @ 16 NONAME ; public: virtual int __thiscall CMDXMLCharacterData::CheckChildren(void)
	?CheckChildren@CMDXMLElement@@UAEHXZ @ 17 NONAME ; public: virtual int __thiscall CMDXMLElement::CheckChildren(void)
	?CheckImmediateChildren@CMDXMLElement@@MAEHXZ @ 18 NONAME ; protected: virtual int __thiscall CMDXMLElement::CheckImmediateChildren(void)
	?Data@CMDXMLCharacterData@@UAEAAVTDesC16@@XZ @ 19 NONAME ; public: virtual class TDesC16 & __thiscall CMDXMLCharacterData::Data(void)
	?E32Dll@@YAHW4TDllReason@@@Z @ 20 NONAME ABSENT ; int __cdecl E32Dll(enum TDllReason)
	?FindIndex@CMDXMLElement@@QAEHABVTDesC16@@@Z @ 21 NONAME ; public: int __thiscall CMDXMLElement::FindIndex(class TDesC16 const &)
	?FirstChildOfType@CMDXMLElement@@QAEPAV1@ABVTDesC16@@@Z @ 22 NONAME ; public: class CMDXMLElement * __thiscall CMDXMLElement::FirstChildOfType(class TDesC16 const &)
	?GetAttribute@CMDXMLElement@@UBEHABVTDesC16@@AAVTPtrC16@@@Z @ 23 NONAME ; public: virtual int __thiscall CMDXMLElement::GetAttribute(class TDesC16 const &,class TPtrC16 &)const 
	?InsertBefore@CMDXMLNode@@QAEHPAV1@0@Z @ 24 NONAME ; public: int __thiscall CMDXMLNode::InsertBefore(class CMDXMLNode *,class CMDXMLNode *)
	?InsertL@CMDXMLCharacterData@@UAEHHAAVTDesC16@@@Z @ 25 NONAME ; public: virtual int __thiscall CMDXMLCharacterData::InsertL(int,class TDesC16 &)
	?IsAttributeSpecified@CMDXMLElement@@UBEHABVTDesC16@@@Z @ 26 NONAME ; public: virtual int __thiscall CMDXMLElement::IsAttributeSpecified(class TDesC16 const &)const 
	?LastChildOfType@CMDXMLElement@@QAEPAV1@ABVTDesC16@@@Z @ 27 NONAME ; public: class CMDXMLElement * __thiscall CMDXMLElement::LastChildOfType(class TDesC16 const &)
	?Length@CMDXMLCharacterData@@UAEHXZ @ 28 NONAME ; public: virtual int __thiscall CMDXMLCharacterData::Length(void)
	?NewL@CMDXMLCDATASection@@SAPAV1@PAVCMDXMLDocument@@@Z @ 29 NONAME ; public: static class CMDXMLCDATASection * __cdecl CMDXMLCDATASection::NewL(class CMDXMLDocument *)
	?NewL@CMDXMLComment@@SAPAV1@PAVCMDXMLDocument@@@Z @ 30 NONAME ; public: static class CMDXMLComment * __cdecl CMDXMLComment::NewL(class CMDXMLDocument *)
	?NewL@CMDXMLDocument@@SAPAV1@AAVMXMLDtd@@@Z @ 31 NONAME ; public: static class CMDXMLDocument * __cdecl CMDXMLDocument::NewL(class MXMLDtd &)
	?NewL@CMDXMLDocumentElement@@SAPAV1@PAVCMDXMLDocument@@@Z @ 32 NONAME ; public: static class CMDXMLDocumentElement * __cdecl CMDXMLDocumentElement::NewL(class CMDXMLDocument *)
	?NewL@CMDXMLElement@@SAPAV1@HPAVCMDXMLDocument@@VTPtrC16@@@Z @ 33 NONAME ; public: static class CMDXMLElement * __cdecl CMDXMLElement::NewL(int,class CMDXMLDocument *,class TPtrC16)
	?NewL@CMDXMLProcessingInstruction@@SAPAV1@PAVCMDXMLDocument@@@Z @ 34 NONAME ; public: static class CMDXMLProcessingInstruction * __cdecl CMDXMLProcessingInstruction::NewL(class CMDXMLDocument *)
	?NewL@CMDXMLText@@SAPAV1@PAVCMDXMLDocument@@@Z @ 35 NONAME ; public: static class CMDXMLText * __cdecl CMDXMLText::NewL(class CMDXMLDocument *)
	?NewLC@CMDXMLCDATASection@@SAPAV1@PAVCMDXMLDocument@@@Z @ 36 NONAME ; public: static class CMDXMLCDATASection * __cdecl CMDXMLCDATASection::NewLC(class CMDXMLDocument *)
	?NewLC@CMDXMLComment@@SAPAV1@PAVCMDXMLDocument@@@Z @ 37 NONAME ; public: static class CMDXMLComment * __cdecl CMDXMLComment::NewLC(class CMDXMLDocument *)
	?NewLC@CMDXMLDocument@@SAPAV1@AAVMXMLDtd@@@Z @ 38 NONAME ; public: static class CMDXMLDocument * __cdecl CMDXMLDocument::NewLC(class MXMLDtd &)
	?NewLC@CMDXMLDocumentElement@@SAPAV1@PAVCMDXMLDocument@@@Z @ 39 NONAME ; public: static class CMDXMLDocumentElement * __cdecl CMDXMLDocumentElement::NewLC(class CMDXMLDocument *)
	?NewLC@CMDXMLElement@@SAPAV1@HPAVCMDXMLDocument@@VTPtrC16@@@Z @ 40 NONAME ; public: static class CMDXMLElement * __cdecl CMDXMLElement::NewLC(int,class CMDXMLDocument *,class TPtrC16)
	?NewLC@CMDXMLProcessingInstruction@@SAPAV1@PAVCMDXMLDocument@@@Z @ 41 NONAME ; public: static class CMDXMLProcessingInstruction * __cdecl CMDXMLProcessingInstruction::NewLC(class CMDXMLDocument *)
	?NewLC@CMDXMLText@@SAPAV1@PAVCMDXMLDocument@@@Z @ 42 NONAME ; public: static class CMDXMLText * __cdecl CMDXMLText::NewLC(class CMDXMLDocument *)
	?NextSameTypeSibling@CMDXMLNode@@IAEPAV1@XZ @ 43 NONAME ; protected: class CMDXMLNode * __thiscall CMDXMLNode::NextSameTypeSibling(void)
	?NodeName@CMDXMLNode@@QAE?AVTPtrC16@@XZ @ 44 NONAME ; public: class TPtrC16  __thiscall CMDXMLNode::NodeName(void)
	?NumAttributes@CMDXMLElement@@QAEHXZ @ 45 NONAME ; public: int __thiscall CMDXMLElement::NumAttributes(void)
	?PreviousSameTypeSibling@CMDXMLNode@@IAEPAV1@XZ @ 46 NONAME ; protected: class CMDXMLNode * __thiscall CMDXMLNode::PreviousSameTypeSibling(void)
	?RemoveAttribute@CMDXMLElement@@UAEHABVTDesC16@@@Z @ 47 NONAME ; public: virtual int __thiscall CMDXMLElement::RemoveAttribute(class TDesC16 const &)
	?RemoveChild@CMDXMLNode@@QAEHPAV1@@Z @ 48 NONAME ; public: int __thiscall CMDXMLNode::RemoveChild(class CMDXMLNode *)
	?ReplaceChild@CMDXMLNode@@QAEHPAV1@0@Z @ 49 NONAME ; public: int __thiscall CMDXMLNode::ReplaceChild(class CMDXMLNode *,class CMDXMLNode *)
	?ReplaceL@CMDXMLCharacterData@@UAEHHHAAVTDesC16@@@Z @ 50 NONAME ; public: virtual int __thiscall CMDXMLCharacterData::ReplaceL(int,int,class TDesC16 &)
	?SetAttributeL@CMDXMLElement@@UAEHABVTDesC16@@0@Z @ 51 NONAME ; public: virtual int __thiscall CMDXMLElement::SetAttributeL(class TDesC16 const &,class TDesC16 const &)
	?SetDataL@CMDXMLCharacterData@@UAEXAAVTDesC16@@@Z @ 52 NONAME ; public: virtual void __thiscall CMDXMLCharacterData::SetDataL(class TDesC16 &)
	?SetDocTypeTagL@CMDXMLDocument@@QAEHABVTDesC16@@@Z @ 53 NONAME ; public: int __thiscall CMDXMLDocument::SetDocTypeTagL(class TDesC16 const &)
	?SetNodeNameL@CMDXMLNode@@IAEXABVTDesC16@@@Z @ 54 NONAME ; protected: void __thiscall CMDXMLNode::SetNodeNameL(class TDesC16 const &)
	?SetVersionTagL@CMDXMLDocument@@QAEHABVTDesC16@@@Z @ 55 NONAME ; public: int __thiscall CMDXMLDocument::SetVersionTagL(class TDesC16 const &)
	?ValidElementNameL@CMDXMLDocument@@QBEHABVTDesC16@@@Z @ 56 NONAME ; public: int __thiscall CMDXMLDocument::ValidElementNameL(class TDesC16 const &)const 
	?PlaceholderForRemovedExport2@CMDXMLDocument@@AAEXXZ @ 57 NONAME ; private: void __thiscall CMDXMLDocument::PlaceholderForRemovedExport2(void)
	?NewL@CMDXMLDocument@@SAPAV1@XZ @ 58 NONAME ; public: static class CMDXMLDocument * __cdecl CMDXMLDocument::NewL(void)
	?NewLC@CMDXMLDocument@@SAPAV1@XZ @ 59 NONAME ; public: static class CMDXMLDocument * __cdecl CMDXMLDocument::NewLC(void)
	?SetAttributeL@CMDXMLElement@@QAEHABVTDesC16@@0H@Z @ 60 NONAME ; int CMDXMLElement::SetAttributeL(class TDesC16 const &, class TDesC16 const &, int)

